searchData={"items":[{"type":"module","title":"BroadwayKafka","doc":"Helpers for BroadwayKafka.\n\nYou can find the Broadway producer in `BroadwayKafka.Producer`.","ref":"BroadwayKafka.html"},{"type":"function","title":"BroadwayKafka.update_topics/2","doc":"Sequentially updates topics in all Broadway producers in the\npipeline given by `name`.","ref":"BroadwayKafka.html#update_topics/2"},{"type":"function","title":"Examples - BroadwayKafka.update_topics/2","doc":"BroadwayKafka.update_topics(MyBroadway, [\"topic_a\", \"topic_b\"])\n    :ok\n\n    BroadwayKafka.update_topics(MyBroadway, [])\n    :ok","ref":"BroadwayKafka.html#update_topics/2-examples"},{"type":"module","title":"BroadwayKafka.Producer","doc":"A Kafka connector for Broadway.\n\nBroadwayKafka can subscribe as a consumer to one or more topics and process streams\nof records within the same consumer group. Communication is done through Kafka's\n[Consumer API](https://kafka.apache.org/documentation.html#consumerapi) using the\n[:brod](https://github.com/klarna/brod/) client.","ref":"BroadwayKafka.Producer.html"},{"type":"module","title":"Options - BroadwayKafka.Producer","doc":"* `:hosts` - Required. A list of host and port tuples or a single string of comma\n    separated HOST:PORT pairs to use for establishing the initial connection to Kafka,\n    e.g. [localhost: 9092]. Examples:\n\n        # Keyword\n        [\"kafka-vm1\": 9092, \"kafka-vm2\": 9092, \"kafka-vm3\": 9092]\n\n        # List of tuples\n        [{\"kafka-vm1\", 9092}, {\"kafka-vm2\", 9092}, {\"kafka-vm3\", 9092}]\n\n        # String\n        \"kafka-vm1:9092,kafka-vm2:9092,kafka-vm3:9092\"\n\n  * `:group_id` - Required. A unique string that identifies the consumer group the producer\n    will belong to.\n\n  * `:topics` - Required. A list of topics that the producer will subscribe to.\n\n  * `:receive_interval` - Optional. The duration (in milliseconds) for which the producer\n    waits before making a request for more messages. Default is 2000 (2 seconds).\n\n  * `:offset_commit_on_ack` - Optional. Tells Broadway to send or not an offset commit\n    request after each acknowledgement. Default is `true`. Setting this value to `false` can\n    increase performance since commit requests will respect the `:offset_commit_interval_seconds`\n    option. However, setting long commit intervals might lead to a large number of duplicated\n    records to be processed after a server restart or connection loss. If that's the case, make\n    sure your logic is idempotent when consuming records to avoid inconsistencies. Also, bear\n    in mind the the negative performance impact might be insignificant if you're using batchers\n    since only one commit request will be performed per batch.\n\n  * `:offset_reset_policy` - Optional. Defines the offset to be used when there's no initial\n    offset in Kafka or if the current offset has expired. Possible values are `:earliest`,\n    `:latest` or {:timestamp, timestamp} (in milliseconds). Default is `:latest`.\n\n  * `:begin_offset` - Optional. Defines how to get the initial offset for the consumers.\n    The possible values are `:assigned` or `:reset`. When set to `:assigned` the starting offset will be the\n    ones returned in the kafka partition assignments (the lastest committed offsets for the consumer group).\n    When set to `:reset`, the starting offset will be dictated by the `:offset_reset_policy` option, either\n    starting from the `:earliest` or the `:latest` offsets of the topic. Default is `:assigned`.\n\n  * `:shared_client` - Optional. When false, it starts one client per producer.\n    When true, it starts a single shared client across all producers (which may reduce\n    memory/resource usage). Default is `false`.\n\n  * `:group_config` - Optional. A list of options used to configure the group\n    coordinator. See the [\"Group config options\"](#module-group-config-options) section below for a list of all available\n    options.\n\n  * `:fetch_config` - Optional. A list of options used when fetching messages. See the\n    [\"Fetch config options\"](#module-fetch-config-options) section below for a list of all available options.\n\n  * `:client_config` - Optional. A list of options used when creating the client. See the\n    [\"Client config options\"](#module-client-config-options) section below for a list of all available options.","ref":"BroadwayKafka.Producer.html#module-options"},{"type":"module","title":"Group config options - BroadwayKafka.Producer","doc":"The available options that will be passed to `:brod`'s group coordinator.\n\n  * `:offset_commit_interval_seconds` - Optional. The time interval between two\n     OffsetCommitRequest messages. Default is 5.\n\n  * `:rejoin_delay_seconds` - Optional. Delay in seconds before rejoining the group. Default is 1.\n\n  * `:session_timeout_seconds` - Optional. Time in seconds the group coordinator broker waits\n    before considering a member 'down' if no heartbeat or any kind of request is received.\n    A group member may also consider the coordinator broker 'down' if no heartbeat response\n    is received in the past N seconds. Default is 30 seconds.\n\n  * `:heartbeat_rate_seconds` - Optional. Time in seconds for member to 'ping' group coordinator.\n    Heartbeats are used to ensure that the consumer's session stays active and\n    to facilitate rebalancing when new consumers join or leave the group.\n    The value must be set lower than `:session_timeout_seconds`, typically equal to or lower than 1/3 of that value.\n    It can be adjusted even lower to control the expected time for normal rebalances. Default is 5 seconds.\n\n  * `:rebalance_timeout_seconds` - Optional. Time in seconds for each worker to join the group once a rebalance has begun.\n    If the timeout is exceeded, then the worker will be removed from the group, which will cause offset commit failures. Default is 30.","ref":"BroadwayKafka.Producer.html#module-group-config-options"},{"type":"module","title":"Fetch config options - BroadwayKafka.Producer","doc":"The available options that will be internally passed to `:brod.fetch/5`.\n\n  * `:min_bytes` - Optional. The minimum amount of data to be fetched from the server.\n    If not enough data is available the request will wait for that much data to accumulate\n    before answering. Default is 1 byte. Setting this value greater than 1 can improve\n    server throughput a bit at the cost of additional latency.\n\n  * `:max_bytes` - Optional. The maximum amount of data to be fetched at a time from a single\n    partition. Default is 1048576 (1 MiB). Setting greater values can improve server\n    throughput at the cost of more memory consumption.\n\n  * `:max_wait_time` - Optional. Time in millisecond. Max number of milliseconds allowed for the broker to collect\n  `min_bytes` of messages in fetch response. Default is 1000ms.","ref":"BroadwayKafka.Producer.html#module-fetch-config-options"},{"type":"module","title":"Client config options - BroadwayKafka.Producer","doc":"The available options that will be internally passed to `:brod.start_client/3`.\n\n  * `:client_id_prefix` - Optional. A string that will be used to build the client id passed to `:brod`. The example\n  value `client_id_prefix: :\"#{Node.self()} -\"` would generate the following connection log from our integration\n  tests:\n\n        20:41:37.717 [info]      :supervisor: {:local, :brod_sup}\n        :started: [\n          pid: #PID<0.286.0>,\n          id: :\"nonode@nohost - Elixir.BroadwayKafka.ConsumerTest.MyBroadway.Broadway.Producer_0.Client\",\n          mfargs: {:brod_client, :start_link,\n           [\n             [localhost: 9092],\n             :\"nonode@nohost - Elixir.BroadwayKafka.ConsumerTest.MyBroadway.Broadway.Producer_0.Client\",\n             [client_id_prefix: :\"nonode@nohost - \"]\n           ]},\n          restart_type: {:permanent, 10},\n          shutdown: 5000,\n          child_type: :worker\n        ]\n\n  * `:sasl` - Optional. A a tuple of mechanism which can be `:plain`, `:scram_sha_256` or `:scram_sha_512`, username and password. See the `:brod`'s\n  [`Authentication Support`](https://github.com/klarna/brod#authentication-support) documentation\n  for more information. Default is no sasl options.\n\n  * `:ssl` - Optional. A boolean or a list of options to use when connecting via SSL/TLS. See the\n  [`tls_client_option`](http://erlang.org/doc/man/ssl.html#type-tls_client_option) documentation\n  for more information. Default is no ssl options.\n\n  * `:connect_timeout` - Optional. Time in milliseconds to be used as a timeout for `:brod`'s communication with Kafka.\n  Default is to use `:brod`'s default timeout which is currently 5 seconds.\n\n  * `:request_timeout` - Optional. Time in milliseconds to be used as a timeout for waiting response from Kafka.\n  Default is to use `:brod`'s default timeout which is currently 240 seconds.\n\n> **Note**: Currently, Broadway does not support all options provided by `:brod`. If you\nhave a scenario where you need any extra option that is not listed above, please open an\nissue, so we can consider adding it.","ref":"BroadwayKafka.Producer.html#module-client-config-options"},{"type":"module","title":"Example - BroadwayKafka.Producer","doc":"Broadway.start_link(MyBroadway,\n      name: MyBroadway,\n      producer: [\n        module: {BroadwayKafka.Producer, [\n          hosts: [localhost: 9092],\n          group_id: \"group_1\",\n          topics: [\"test\"],\n        ]},\n        concurrency: 1\n      ],\n      processors: [\n        default: [\n          concurrency: 10\n        ]\n      ]\n    )","ref":"BroadwayKafka.Producer.html#module-example"},{"type":"module","title":"Concurrency and partitioning - BroadwayKafka.Producer","doc":"The concurrency model provided by Kafka is based on partitioning, i.e., the more partitions\nyou have, the more concurrency you get. However, in order to take advantage of this model\nyou need to set up the `:concurrency` options for your processors and batchers accordingly. Having\nless concurrency than topic/partitions assigned will result in individual processors handling more\nthan one partition, decreasing the overall level of concurrency. Therefore, if you want to\nalways be able to process messages at maximum concurrency (assuming you have enough resources\nto do it), you should increase the concurrency up front to make sure you have enough\nprocessors to handle the extra messages received from new partitions assigned.\n\n> **Note**: Even if you don't plan to add more partitions to a Kafka topic, your pipeline can still\nreceive more assignments than planned. For instance, if another consumer crashes, the server\nwill reassign all its topic/partition to other available consumers, including any Broadway\nproducer subscribed to the same topic.","ref":"BroadwayKafka.Producer.html#module-concurrency-and-partitioning"},{"type":"module","title":"Handling failed messages - BroadwayKafka.Producer","doc":"`BroadwayKafka` never stops the flow of the stream, i.e. it will **always ack** the messages\neven when they fail. Unlike queue-based connectors, where you can mark a single message as failed.\nIn Kafka that's not possible due to its single offset per topic/partition ack strategy. If you\nwant to reprocess failed messages, you need to roll your own strategy. A possible way to do that\nis to implement `c:Broadway.handle_failed/2` and send failed messages to a separated stream or queue for\nlater processing.","ref":"BroadwayKafka.Producer.html#module-handling-failed-messages"},{"type":"module","title":"Message metadata - BroadwayKafka.Producer","doc":"When producing messages, the following information will be passed to\n[`Broadway.Message`](`t:Broadway.Message.t/0`)'s metadata.\n\n  * `topic` - The topic the message was published.\n\n  * `partition` - The topic partition.\n\n  * `offset` - The offset assigned to the message inside the partition.\n\n  * `key` - The partition key.\n\n  * `ts` - A timestamp associated with the message.\n\n  * `headers` - The headers of the message.","ref":"BroadwayKafka.Producer.html#module-message-metadata"},{"type":"module","title":"Telemetry - BroadwayKafka.Producer","doc":"This producer emits a few [Telemetry](https://github.com/beam-telemetry/telemetry)\nevents which are listed below.\n\n  * `[:broadway_kafka, :assignments_revoked, :start | :stop | :exception]` spans -\n    these events are emitted in \"span style\" when receiving assignments revoked call from consumer group coordinator\n    See `:telemetry.span/3`.","ref":"BroadwayKafka.Producer.html#module-telemetry"},{"type":"macro","title":"BroadwayKafka.Producer.brod_received_assignment/1","doc":"","ref":"BroadwayKafka.Producer.html#brod_received_assignment/1"},{"type":"macro","title":"BroadwayKafka.Producer.brod_received_assignment/2","doc":"","ref":"BroadwayKafka.Producer.html#brod_received_assignment/2"},{"type":"macro","title":"BroadwayKafka.Producer.kafka_message/1","doc":"","ref":"BroadwayKafka.Producer.html#kafka_message/1"},{"type":"macro","title":"BroadwayKafka.Producer.kafka_message/2","doc":"","ref":"BroadwayKafka.Producer.html#kafka_message/2"}],"producer":{"name":"ex_doc","version":[48,46,51,49,46,50]},"content_type":"text/markdown"}